==> tengits_widgets-0.0.1.tar.gz: lib/progress/src/progress_widget.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:tengits_widgets/tengits_widgets.dart';

class TLProcessWidget<T> extends StatefulWidget {
  const TLProcessWidget({
    Key? key,
    this.processController,
    required this.processRequestData,
    required this.contentBuilder,
  }) : super(key: key);

  final TProcessController? processController;
  final Future<List<T>?> Function() processRequestData;
  final Widget Function(BuildContext context, List<T> datas) contentBuilder;

  @override
  State<TLProcessWidget> createState() => _TLProcessWidgetState<T>();
}

class _TLProcessWidgetState<T> extends State<TLProcessWidget<T>> {
  //
  late TProcessController? _processController;
  //
  List<T> _datas = <T>[];
  //
  TLProgressStatus _status = TLProgressStatus.loading();

  @override
  void initState() {
    ///
    _processController = widget.processController;
    _processController?.addListener(_handleRefreshListener);

    ///
    _requestProcess();

    super.initState();
  }

  _handleRefreshListener() {
    _requestProcess();
  }

  Future<bool> _requestProcess() async {
    if (mounted) {
      setState(() {
        _datas.clear();
        _status = TLProgressStatus.loading();
      });
    }
    var rspData = await widget.processRequestData();
    if (rspData == null) {
      if (mounted) {
        setState(() {
          _status = TLProgressStatus.error();
        });
      }
    } else {
      if (mounted) {
        setState(() {
          _datas = rspData;
          if (_datas.isEmpty) {
            _status = TLProgressStatus.empty();
          } else {
            _status = TLProgressStatus.success();
          }
        });
      }
    }
    return rspData != null;
  }

  @override
  Widget build(BuildContext context) {
    return Builder(
      builder: (context) {
        if (_status.isSuccess) {
          return widget.contentBuilder(context, _datas);
        }
        if (_status.isLoading) {
          return SizedBox(
            height: 200.h,
            child: const TLProgressLoadingWidget(),
          );
        } else {
          return SizedBox(
            height: 200.h,
            child: TLNoDataWidget(
              title: "暂无数据, 点击刷新",
              onTap: () => _requestProcess(),
            ),
          );
        }
      },
    );
  }

  @override
  void dispose() {
    ///
    _processController?.removeListener(_handleRefreshListener);

    super.dispose();
  }
}

class TProcessController with ChangeNotifier {
  TProcessController();

  void refresh() {
    notifyListeners();
  }
}

class TLProgressLoadingWidget extends StatelessWidget {
  const TLProgressLoadingWidget({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Container(
      alignment: Alignment.center,
      padding: EdgeInsets.symmetric(vertical: 20.w, horizontal: 30.h),
      decoration: BoxDecoration(
        color: Colors.transparent,
        borderRadius: BorderRadius.circular(15.r),
      ),
      child: Column(
        mainAxisAlignment: MainAxisAlignment.center,
        mainAxisSize: MainAxisSize.min,
        crossAxisAlignment: CrossAxisAlignment.center,
        children: [
          CircularProgressIndicator(
            color: Colors.black,
            strokeWidth: 3.r,
            valueColor: const AlwaysStoppedAnimation(Colors.black),
          )
        ],
      ),
    );
  }
}

class TLNoDataWidget extends StatelessWidget {
  const TLNoDataWidget({
    Key? key,
    this.title = "",
    this.onTap,
  }) : super(key: key);

  final String title;
  final GestureTapCallback? onTap;

  @override
  Widget build(BuildContext context) {
    return GestureDetector(
      onTap: onTap,
      child: Container(
        alignment: Alignment.center,
        child: Column(
          mainAxisAlignment: MainAxisAlignment.center,
          mainAxisSize: MainAxisSize.min,
          crossAxisAlignment: CrossAxisAlignment.center,
          children: [
            Image(
              image: ImageUtils.getAssetImage("assets/images/no_data.png", package: "tengits_common"),
              width: 160.w,
              height: 160.h,
              fit: BoxFit.fill,
            ),
            SizedBox(
              height: 16.h,
            ),
            Text(title, style: TextStyle(color: const Color(0xFF969799), fontSize: 16.sp)),
          ],
        ),
      ),
    );
  }
}

==> tengits_widgets-0.0.4.tar.gz: lib/progress/src/progress_widget.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:tengits_widgets/tengits_widgets.dart';

class TLProcessWidget<T> extends StatefulWidget {
  const TLProcessWidget({
    Key? key,
    this.processController,
    required this.processRequestData,
    required this.contentBuilder,
  }) : super(key: key);

  final TProcessController? processController;
  final Future<List<T>?> Function() processRequestData;
  final Widget Function(BuildContext context, List<T> datas) contentBuilder;

  @override
  State<TLProcessWidget> createState() => _TLProcessWidgetState<T>();
}

class _TLProcessWidgetState<T> extends State<TLProcessWidget<T>> {
  //
  late TProcessController? _processController;
  //
  List<T> _datas = <T>[];
  //
  TLProgressStatus _status = TLProgressStatus.loading();

  @override
  void initState() {
    ///
    _processController = widget.processController;
    _processController?.addListener(_handleRefreshListener);

    ///
    _requestProcess();

    super.initState();
  }

  _handleRefreshListener() {
    _requestProcess();
  }

  Future<bool> _requestProcess() async {
    if (mounted) {
      setState(() {
        _datas.clear();
        _status = TLProgressStatus.loading();
      });
    }
    var rspData = await widget.processRequestData();
    if (rspData == null) {
      if (mounted) {
        setState(() {
          _status = TLProgressStatus.error();
        });
      }
    } else {
      if (mounted) {
        setState(() {
          _datas = rspData;
          if (_datas.isEmpty) {
            _status = TLProgressStatus.empty();
          } else {
            _status = TLProgressStatus.success();
          }
        });
      }
    }
    return rspData != null;
  }

  @override
  Widget build(BuildContext context) {
    return Builder(
      builder: (context) {
        if (_status.isSuccess) {
          return widget.contentBuilder(context, _datas);
        }
        if (_status.isLoading) {
          return SizedBox(
            height: 200.h,
            child: const TLProgressLoadingWidget(),
          );
        } else {
          return SizedBox(
            height: 200.h,
            child: TLNoDataWidget(
              title: "暂无数据, 点击刷新",
              onTap: () => _requestProcess(),
            ),
          );
        }
      },
    );
  }

  @override
  void dispose() {
    ///
    _processController?.removeListener(_handleRefreshListener);

    super.dispose();
  }
}

class TProcessController with ChangeNotifier {
  TProcessController();

  void refresh() {
    notifyListeners();
  }
}

class TLProgressLoadingWidget extends StatelessWidget {
  const TLProgressLoadingWidget({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Container(
      alignment: Alignment.center,
      padding: EdgeInsets.symmetric(vertical: 20.w, horizontal: 30.h),
      decoration: BoxDecoration(
        color: Colors.transparent,
        borderRadius: BorderRadius.circular(15.r),
      ),
      child: Column(
        mainAxisAlignment: MainAxisAlignment.center,
        mainAxisSize: MainAxisSize.min,
        crossAxisAlignment: CrossAxisAlignment.center,
        children: [
          CircularProgressIndicator(
            color: Colors.black,
            strokeWidth: 3.r,
            valueColor: const AlwaysStoppedAnimation(Colors.black),
          )
        ],
      ),
    );
  }
}

class TLNoDataWidget extends StatelessWidget {
  const TLNoDataWidget({
    Key? key,
    this.title = "",
    this.onTap,
  }) : super(key: key);

  final String title;
  final GestureTapCallback? onTap;

  @override
  Widget build(BuildContext context) {
    return GestureDetector(
      onTap: onTap,
      child: Container(
        alignment: Alignment.center,
        child: Column(
          mainAxisAlignment: MainAxisAlignment.center,
          mainAxisSize: MainAxisSize.min,
          crossAxisAlignment: CrossAxisAlignment.center,
          children: [
            Image(
              image: ImageUtils.getAssetImageProvider("assets/images/no_data.png", package: "tengits_common"),
              width: 160.w,
              height: 160.h,
              fit: BoxFit.fill,
            ),
            SizedBox(
              height: 16.h,
            ),
            Text(title, style: TextStyle(color: const Color(0xFF969799), fontSize: 16.sp)),
          ],
        ),
      ),
    );
  }
}
